<?php
/**
 * Theme functions and definitions
 *
 * @package civil_engineering
 */

// enque files
if ( ! function_exists( 'civil_engineering_enqueue_styles' ) ) :
	/**
	 * Load assets.
	 *
	 * @since 1.0.0
	 */
	function civil_engineering_enqueue_styles() {
		wp_enqueue_style( 'architecture-building-style-parent', get_template_directory_uri() . '/style.css' );
		wp_enqueue_style( 'civil-engineering-style', get_stylesheet_directory_uri() . '/style.css', array( 'architecture-building-style-parent' ), '1.0.0' );
		wp_enqueue_script( 'civil-engineering-custom-js', get_stylesheet_directory_uri() . '/assets/js/theme-script.js', array('jquery'), true);
		
		require get_parent_theme_file_path( 'inc/extra_customization.php' );
		wp_add_inline_style( 'civil-engineering-style',$architecture_building_custom_style );
		require get_theme_file_path( 'inc/extra_customization.php' );
		wp_add_inline_style( 'civil-engineering-style',$architecture_building_custom_style );

		// blocks css
        wp_enqueue_style( 'civil-engineering-block-style', get_theme_file_uri( '/assets/css/blocks.css' ), array( 'civil-engineering-style' ), '1.0' );
	}
endif;
add_action( 'wp_enqueue_scripts', 'civil_engineering_enqueue_styles', 99 );

// theme setup
function civil_engineering_setup() {
	add_theme_support( 'align-wide' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( "responsive-embeds" );
	add_theme_support( "wp-block-styles" );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_theme_support('custom-background',array(
		'default-color' => 'ffffff',
	));
	add_image_size( 'civil-engineering-featured-image', 2000, 1200, true );
	add_image_size( 'civil-engineering-thumbnail-avatar', 100, 100, true );

	$GLOBALS['content_width'] = 525;
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'civil-engineering' ),
	) );

	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'       => 250,
		'height'      => 250,
		'flex-width'  => true,
		'flex-height' => true,
	) );

	/*
	* This theme styles the visual editor to resemble the theme style,
	* specifically font, colors, and column width.
	*/
	add_editor_style( array( 'assets/css/editor-style.css' ) );
}
add_action( 'after_setup_theme', 'civil_engineering_setup' );

// custom header setup
function civil_engineering_custom_header_setup() {
    add_theme_support( 'custom-header', apply_filters( 'civil_engineering_custom_header_args', array(
        'default-image'          => get_theme_file_uri( '/assets/images/header-img.png' ),
        'default-text-color'     => 'fff',
        'header-text'            => false,
        'width'                  => 1200,
        'height'                 => 80,
        'flex-width'             => true,
        'flex-height'            => true,
        'wp-head-callback'       => 'architecture_building_header_style',
    ) ) );

    register_default_headers( array(
        'default-image' => array(
            'url'           => '%s/assets/images/header-img.png',
            'thumbnail_url' => '%s/assets/images/header-img.png',
            'description'   => __( 'Default Header Image', 'civil-engineering' ),
        ),
    ) );
}
add_action( 'after_setup_theme', 'civil_engineering_custom_header_setup' );

// widgets
function civil_engineering_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'civil-engineering' ),
		'id'            => 'sidebar-1',
		'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'civil-engineering' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'civil-engineering' ),
		'id'            => 'sidebar-2',
		'description'   => __( 'Add widgets here to appear in your pages and posts', 'civil-engineering' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar 3', 'civil-engineering' ),
		'id'            => 'sidebar-3',
		'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'civil-engineering' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 1', 'civil-engineering' ),
		'id'            => 'footer-1',
		'description'   => __( 'Add widgets here to appear in your footer.', 'civil-engineering' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 2', 'civil-engineering' ),
		'id'            => 'footer-2',
		'description'   => __( 'Add widgets here to appear in your footer.', 'civil-engineering' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 3', 'civil-engineering' ),
		'id'            => 'footer-3',
		'description'   => __( 'Add widgets here to appear in your footer.', 'civil-engineering' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 4', 'civil-engineering' ),
		'id'            => 'footer-4',
		'description'   => __( 'Add widgets here to appear in your footer.', 'civil-engineering' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'civil_engineering_widgets_init' );

// remove sections
function civil_engineering_customize_register() {
  	global $wp_customize;
	$wp_customize->remove_section( 'architecture_building_pro' );
	$wp_customize->remove_setting('architecture_building_slider_content_alignment');
	$wp_customize->remove_control('architecture_building_slider_content_alignment');
	$wp_customize->remove_setting('architecture_building_footer_text');
	$wp_customize->remove_control('architecture_building_footer_text');
}
add_action( 'customize_register', 'civil_engineering_customize_register', 11 );

// customizer dropdown
function civil_engineering_contact_dropdown(){
	if(get_option('civil_engineering_contact_enable') == true ) {
		return true;
	}
	return false;
}
function civil_engineering_about_us_dropdown(){
	if(get_option('civil_engineering_about_us_enable') == true ) {
		return true;
	}
	return false;
}

// customizer
function civil_engineering_customize( $wp_customize ) {

	wp_enqueue_style('customizercustom_css', esc_url( get_stylesheet_directory_uri() ). '/assets/css/customizer.css');

	require get_theme_file_path( 'inc/custom-control.php' );

	// pro section
	$wp_customize->add_section('civil_engineering_pro', array(
		'title'    => __('UPGRADE ENGINEERING PREMIUM', 'civil-engineering'),
		'priority' => 1,
	));
	$wp_customize->add_setting('civil_engineering_pro', array(
		'default'           => null,
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control(new Civil_Engineering_Pro_Control($wp_customize, 'civil_engineering_pro', array(
		'label'    => __('ENGINEERING PREMIUM', 'civil-engineering'),
		'section'  => 'civil_engineering_pro',
		'settings' => 'civil_engineering_pro',
		'priority' => 1,
	)));

	// slider content alignment
	$wp_customize->add_setting( 'civil_engineering_slider_content_alignment',
		array(
			'default' => 'CENTER-ALIGN',
			'transport' => 'refresh',
			'sanitize_callback' => 'architecture_building_sanitize_choices'
		)
	);
	$wp_customize->add_control( new Civil_Engineering_Text_Radio_Button_Custom_Control( $wp_customize, 'civil_engineering_slider_content_alignment',
		array(
			'type' => 'select',
			'label' => esc_html__( 'Slider Content Alignment', 'civil-engineering' ),
			'section' => 'architecture_building_slider_section',
			'choices' => array(
				'LEFT-ALIGN' => __('LEFT','civil-engineering'),
	            'CENTER-ALIGN' => __('CENTER','civil-engineering'),
	            'RIGHT-ALIGN' => __('RIGHT','civil-engineering'),
			),
			'active_callback' => 'architecture_building_slider_dropdown',
		)
	) );
	// Contact Us
    $wp_customize->add_section('civil_engineering_contact_us',array(
        'title' => __('Information Section', 'civil-engineering'),
        'priority' => 4,
        'panel' => 'architecture_building_custompage_panel',
    ) );
    $wp_customize->add_setting( 'civil_engineering_contact_heading', array(
		'default'           => '',
		'transport'         => 'refresh',
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wp_customize->add_control( new Civil_Engineering_Customizer_Customcontrol_Section_Heading( $wp_customize, 'civil_engineering_contact_heading', array(
		'label'       => esc_html__( 'Information Section Settings', 'civil-engineering' ),	
		'section'     => 'civil_engineering_contact_us',
		'settings'    => 'civil_engineering_contact_heading',
		'priority'    => 1,
	) ) );
	$wp_customize->add_setting(
		'civil_engineering_contact_enable',
		array(
			'type'                 => 'option',
			'capability'           => 'edit_theme_options',
			'theme_supports'       => '',
			'default'              => '',
			'transport'            => 'refresh',
			'sanitize_callback'    => 'architecture_building_callback_sanitize_switch',
		)
	);
	$wp_customize->add_control(
		new Civil_Engineering_Customizer_Customcontrol_Switch(
			$wp_customize,
			'civil_engineering_contact_enable',
			array(
				'settings'        => 'civil_engineering_contact_enable',
				'section'         => 'civil_engineering_contact_us',
				'label'           => __( 'Check To show Section', 'civil-engineering' ),				
				'choices'		  => array(
					'1'      => __( 'On', 'civil-engineering' ),
					'off'    => __( 'Off', 'civil-engineering' ),
				),
				'active_callback' => '',
				'priority'   => 1,
			)
		)
	);
	$wp_customize->add_setting('civil_engineering_contact_us_heading',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('civil_engineering_contact_us_heading',array(
		'label' => esc_html__('Section Heading','civil-engineering'),
		'section' => 'civil_engineering_contact_us',
		'setting' => 'civil_engineering_contact_us_heading',
		'type'    => 'text',
		'active_callback' => 'civil_engineering_contact_dropdown',
	));
	$wp_customize->add_setting('civil_engineering_contact_us_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('civil_engineering_contact_us_text',array(
		'label' => esc_html__('Section Text','civil-engineering'),
		'section' => 'civil_engineering_contact_us',
		'setting' => 'civil_engineering_contact_us_text',
		'type'    => 'text',
		'active_callback' => 'civil_engineering_contact_dropdown',
	));
	$wp_customize->add_setting('civil_engineering_contact_us_btn_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('civil_engineering_contact_us_btn_text',array(
		'label' => esc_html__('Button Text','civil-engineering'),
		'section' => 'civil_engineering_contact_us',
		'setting' => 'civil_engineering_contact_us_btn_text',
		'type'    => 'text',
		'active_callback' => 'civil_engineering_contact_dropdown',
	));
	$wp_customize->add_setting('civil_engineering_contact_us_btn_url',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control('civil_engineering_contact_us_btn_url',array(
		'label' => esc_html__('Button URL','civil-engineering'),
		'section' => 'civil_engineering_contact_us',
		'setting' => 'civil_engineering_contact_us_btn_url',
		'type'    => 'url',
		'active_callback' => 'civil_engineering_contact_dropdown',
	));

	// About Us Section
	$wp_customize->add_section( 'civil_engineering_about_us_section' , array(
    	'title'      => __( 'About Us Settings', 'civil-engineering' ),
		'priority'   => 5,
		'panel' => 'architecture_building_custompage_panel',
	) );
	$wp_customize->add_setting( 'civil_engineering_about_heading', array(
			'default'           => '',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
	) );
	$wp_customize->add_control( new Civil_Engineering_Customizer_Customcontrol_Section_Heading( $wp_customize, 'civil_engineering_about_heading', array(
		'label'       => esc_html__( 'About Us Settings', 'civil-engineering' ),	
		'section'     => 'civil_engineering_about_us_section',
		'settings'    => 'civil_engineering_about_heading',
		'priority'    => 1,
	) ) );
	$wp_customize->add_setting(
		'civil_engineering_about_us_enable',
		array(
			'type'                 => 'option',
			'capability'           => 'edit_theme_options',
			'theme_supports'       => '',
			'default'              => '',
			'transport'            => 'refresh',
			'sanitize_callback'    => 'architecture_building_callback_sanitize_switch',
		)
	);
	$wp_customize->add_control(
		new Civil_Engineering_Customizer_Customcontrol_Switch(
			$wp_customize,
			'civil_engineering_about_us_enable',
			array(
				'settings'        => 'civil_engineering_about_us_enable',
				'section'         => 'civil_engineering_about_us_section',
				'label'           => __( 'Check To show Section', 'civil-engineering' ),				
				'choices'		  => array(
					'1'      => __( 'On', 'civil-engineering' ),
					'off'    => __( 'Off', 'civil-engineering' ),
				),
				'active_callback' => '',
				'priority'   => 1,
			)
		)
	);
	$wp_customize->add_setting('civil_engineering_about_us_title',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('civil_engineering_about_us_title',array(
		'label' => esc_html__('Section Title','civil-engineering'),
		'section' => 'civil_engineering_about_us_section',
		'setting' => 'civil_engineering_about_us_title',
		'type'    => 'text',
		'active_callback' => 'civil_engineering_about_us_dropdown',
	));
	$wp_customize->add_setting('civil_engineering_about_us_settigs',array(
		'sanitize_callback' => 'architecture_building_sanitize_dropdown_pages',
	));
	$wp_customize->add_control('civil_engineering_about_us_settigs',array(
		'type'    => 'dropdown-pages',
		'label' => __('Select Page','civil-engineering'),
		'section' => 'civil_engineering_about_us_section',
		'active_callback' => 'civil_engineering_about_us_dropdown',
	));

	$wp_customize->add_setting('civil_engineering_footer_text',array(
		'default'	=> 'Civil Engineering WordPress Theme',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('civil_engineering_footer_text',array(
		'label'	=> esc_html__('Copyright Text','civil-engineering'),
		'section'	=> 'architecture_building_footer_copyright',
		'type'		=> 'textarea'
	));
}
add_action( 'customize_register', 'civil_engineering_customize' );

// comments
function civil_engineering_enqueue_comments_reply() {
  if( is_singular() && comments_open() && ( get_option( 'thread_comments' ) == 1) ) {
    // Load comment-reply.js (into footer)
    wp_enqueue_script( 'comment-reply', '/wp-includes/js/comment-reply.min.js', array(), false, true );
  }
}
add_action(  'wp_enqueue_scripts', 'civil_engineering_enqueue_comments_reply' );

// Footer Text
function civil_engineering_copyright_link() {
    $footer_text = get_theme_mod('civil_engineering_footer_text', esc_html__('Civil Engineering WordPress Theme', 'civil-engineering'));
    $credit_link = esc_url('https://www.ovationthemes.com/wordpress/free-engineering-wordpress-theme/');

    echo '<a href="' . $credit_link . '" target="_blank">' . esc_html($footer_text) . '<span class="footer-copyright">' . esc_html__(' By Ovation Themes', 'civil-engineering') . '</span></a>';
}

if ( ! defined( 'CIVIL_ENGINEERING_PRO_LINK' ) ) {
	define('CIVIL_ENGINEERING_PRO_LINK',__('https://www.ovationthemes.com/wordpress/civil-engineering-wordpress-theme/','civil-engineering'));
}
if ( ! defined( 'ARCHITECTURE_BUILDING_SUPPORT' ) ) {
define('ARCHITECTURE_BUILDING_SUPPORT',__('https://wordpress.org/support/theme/civil-engineering','civil-engineering'));
}
if ( ! defined( 'ARCHITECTURE_BUILDING_REVIEW' ) ) {
define('ARCHITECTURE_BUILDING_REVIEW',__('https://wordpress.org/support/theme/civil-engineering/reviews/#new-post','civil-engineering'));
}
if ( ! defined( 'ARCHITECTURE_BUILDING_LIVE_DEMO' ) ) {
define('ARCHITECTURE_BUILDING_LIVE_DEMO',__('https://www.ovationthemes.com/demos/civil-engineering/','civil-engineering'));
}
if ( ! defined( 'ARCHITECTURE_BUILDING_BUY_PRO' ) ) {
define('ARCHITECTURE_BUILDING_BUY_PRO',__('https://www.ovationthemes.com/wordpress/civil-engineering-wordpress-theme/','civil-engineering'));
}
if ( ! defined( 'ARCHITECTURE_BUILDING_PRO_DOC' ) ) {
define('ARCHITECTURE_BUILDING_PRO_DOC',__('https://www.ovationthemes.com/docs/ot-civil-engineering-pro-doc','civil-engineering'));
}
if ( ! defined( 'ARCHITECTURE_BUILDING_FREE_DOC' ) ) {
define('ARCHITECTURE_BUILDING_FREE_DOC',__('http://www.ovationthemes.com/docs/ot-civil-engineering-free-doc/','civil-engineering'));
}
if ( ! defined( 'ARCHITECTURE_BUILDING_THEME_NAME' ) ) {
define('ARCHITECTURE_BUILDING_THEME_NAME',__('Premium Engineering Theme','civil-engineering'));
}

/* Pro control */
if (class_exists('WP_Customize_Control') && !class_exists('Civil_Engineering_Pro_Control')):
    class Civil_Engineering_Pro_Control extends WP_Customize_Control{

    public function render_content(){?>
        <label style="overflow: hidden; zoom: 1;">
            <div class="col-md upsell-btn">
                <a href="<?php echo esc_url( CIVIL_ENGINEERING_PRO_LINK ); ?>" target="blank" class="btn btn-success btn"><?php esc_html_e('UPGRADE ENGINEERING PREMIUM','civil-engineering');?> </a>
            </div>
            <div class="col-md">
                <img class="civil_engineering_img_responsive " src="<?php echo esc_url( get_stylesheet_directory_uri() ); ?>/screenshot.png">
            </div>
            <div class="col-md">
                <h3 style="margin-top:10px; margin-left: 20px; text-decoration:underline; color:#333;"><?php esc_html_e('ENGINEERING PREMIUM - Features', 'civil-engineering'); ?></h3>
                <ul style="padding-top:10px">
                    <li class="upsell-civil_engineering"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Responsive Design', 'civil-engineering');?> </li>
                    <li class="upsell-civil_engineering"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Boxed or fullwidth layout', 'civil-engineering');?> </li>
                    <li class="upsell-civil_engineering"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Shortcode Support', 'civil-engineering');?> </li>
                    <li class="upsell-civil_engineering"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Demo Importer', 'civil-engineering');?> </li>
                    <li class="upsell-civil_engineering"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Section Reordering', 'civil-engineering');?> </li>
                    <li class="upsell-civil_engineering"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Contact Page Template', 'civil-engineering');?> </li>
                    <li class="upsell-civil_engineering"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Multiple Blog Layouts', 'civil-engineering');?> </li>
                    <li class="upsell-civil_engineering"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Unlimited Color Options', 'civil-engineering');?> </li>
                    <li class="upsell-civil_engineering"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Designed with HTML5 and CSS3', 'civil-engineering');?> </li>
                    <li class="upsell-civil_engineering"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Customizable Design & Code', 'civil-engineering');?> </li>
                    <li class="upsell-civil_engineering"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Cross Browser Support', 'civil-engineering');?> </li>
                    <li class="upsell-civil_engineering"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Detailed Documentation Included', 'civil-engineering');?> </li>
                    <li class="upsell-civil_engineering"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Stylish Custom Widgets', 'civil-engineering');?> </li>
                    <li class="upsell-civil_engineering"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Patterns Background', 'civil-engineering');?> </li>
                    <li class="upsell-civil_engineering"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('WPML Compatible (Translation Ready)', 'civil-engineering');?> </li>
                    <li class="upsell-civil_engineering"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Woo-commerce Compatible', 'civil-engineering');?> </li>
                    <li class="upsell-civil_engineering"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Full Support', 'civil-engineering');?> </li>
                    <li class="upsell-civil_engineering"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('10+ Sections', 'civil-engineering');?> </li>
                    <li class="upsell-civil_engineering"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Live Customizer', 'civil-engineering');?> </li>
                    <li class="upsell-civil_engineering"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('AMP Ready', 'civil-engineering');?> </li>
                    <li class="upsell-civil_engineering"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Clean Code', 'civil-engineering');?> </li>
                    <li class="upsell-civil_engineering"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('SEO Friendly', 'civil-engineering');?> </li>
                    <li class="upsell-civil_engineering"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Supper Fast', 'civil-engineering');?> </li>
                </ul>
            </div>
            <div class="col-md upsell-btn upsell-btn-bottom">
                <a href="<?php echo esc_url( CIVIL_ENGINEERING_PRO_LINK ); ?>" target="blank" class="btn btn-success btn"><?php esc_html_e('UPGRADE ENGINEERING PREMIUM','civil-engineering');?> </a>
            </div>
        </label>
    <?php } }
endif;
